@@ -16,6 +16,7 @@ from datetime import datetime
 from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
+    AssetTypeType,
     CodeType,
     JobErrorLimitNameType,
     JobErrorResourceTypesType,
@@ -25,10 +26,6 @@ from .literals import (
     TypeType,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -80,6 +77,8 @@ __all__ = (
     "ImportAssetFromSignedUrlJobErrorDetailsTypeDef",
     "ImportAssetFromSignedUrlRequestDetailsTypeDef",
     "ImportAssetFromSignedUrlResponseDetailsTypeDef",
+    "ImportAssetsFromRedshiftDataSharesRequestDetailsTypeDef",
+    "ImportAssetsFromRedshiftDataSharesResponseDetailsTypeDef",
     "ImportAssetsFromS3RequestDetailsTypeDef",
     "ImportAssetsFromS3ResponseDetailsTypeDef",
     "JobEntryTypeDef",
@@ -98,6 +97,8 @@ __all__ = (
     "ListTagsForResourceResponseTypeDef",
     "OriginDetailsTypeDef",
     "PaginatorConfigTypeDef",
+    "RedshiftDataShareAssetSourceEntryTypeDef",
+    "RedshiftDataShareAssetTypeDef",
     "RequestDetailsTypeDef",
     "ResponseDetailsTypeDef",
     "ResponseMetadataTypeDef",
@@ -152,6 +153,7 @@ AssetDetailsTypeDef = TypedDict(
     "AssetDetailsTypeDef",
     {
         "S3SnapshotAsset": "S3SnapshotAssetTypeDef",
+        "RedshiftDataShareAsset": "RedshiftDataShareAssetTypeDef",
     },
     total=False,
 )
@@ -161,7 +163,7 @@ _RequiredAssetEntryTypeDef = TypedDict(
     {
         "Arn": str,
         "AssetDetails": "AssetDetailsTypeDef",
-        "AssetType": Literal["S3_SNAPSHOT"],
+        "AssetType": AssetTypeType,
         "CreatedAt": datetime,
         "DataSetId": str,
         "Id": str,
@@ -245,7 +247,7 @@ CancelJobRequestRequestTypeDef = TypedDict(
 _RequiredCreateDataSetRequestRequestTypeDef = TypedDict(
     "_RequiredCreateDataSetRequestRequestTypeDef",
     {
-        "AssetType": Literal["S3_SNAPSHOT"],
+        "AssetType": AssetTypeType,
         "Description": str,
         "Name": str,
     },
@@ -269,7 +271,7 @@ CreateDataSetResponseTypeDef = TypedDict(
     "CreateDataSetResponseTypeDef",
     {
         "Arn": str,
-        "AssetType": Literal["S3_SNAPSHOT"],
+        "AssetType": AssetTypeType,
         "CreatedAt": datetime,
         "Description": str,
         "Id": str,
@@ -369,7 +371,7 @@ _RequiredDataSetEntryTypeDef = TypedDict(
     "_RequiredDataSetEntryTypeDef",
     {
         "Arn": str,
-        "AssetType": Literal["S3_SNAPSHOT"],
+        "AssetType": AssetTypeType,
         "CreatedAt": datetime,
         "Description": str,
         "Id": str,
@@ -566,6 +568,7 @@ _OptionalExportRevisionsToS3ResponseDetailsTypeDef = TypedDict(
     "_OptionalExportRevisionsToS3ResponseDetailsTypeDef",
     {
         "Encryption": "ExportServerSideEncryptionTypeDef",
+        "EventActionArn": str,
     },
     total=False,
 )
@@ -613,7 +616,7 @@ GetAssetResponseTypeDef = TypedDict(
     {
         "Arn": str,
         "AssetDetails": "AssetDetailsTypeDef",
-        "AssetType": Literal["S3_SNAPSHOT"],
+        "AssetType": AssetTypeType,
         "CreatedAt": datetime,
         "DataSetId": str,
         "Id": str,
@@ -636,7 +639,7 @@ GetDataSetResponseTypeDef = TypedDict(
     "GetDataSetResponseTypeDef",
     {
         "Arn": str,
-        "AssetType": Literal["S3_SNAPSHOT"],
+        "AssetType": AssetTypeType,
         "CreatedAt": datetime,
         "Description": str,
         "Id": str,
@@ -759,6 +762,24 @@ class ImportAssetFromSignedUrlResponseDetailsTypeDef(
     pass
 
 
+ImportAssetsFromRedshiftDataSharesRequestDetailsTypeDef = TypedDict(
+    "ImportAssetsFromRedshiftDataSharesRequestDetailsTypeDef",
+    {
+        "AssetSources": Sequence["RedshiftDataShareAssetSourceEntryTypeDef"],
+        "DataSetId": str,
+        "RevisionId": str,
+    },
+)
+
+ImportAssetsFromRedshiftDataSharesResponseDetailsTypeDef = TypedDict(
+    "ImportAssetsFromRedshiftDataSharesResponseDetailsTypeDef",
+    {
+        "AssetSources": List["RedshiftDataShareAssetSourceEntryTypeDef"],
+        "DataSetId": str,
+        "RevisionId": str,
+    },
+)
+
 ImportAssetsFromS3RequestDetailsTypeDef = TypedDict(
     "ImportAssetsFromS3RequestDetailsTypeDef",
     {
@@ -981,6 +1002,20 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
+RedshiftDataShareAssetSourceEntryTypeDef = TypedDict(
+    "RedshiftDataShareAssetSourceEntryTypeDef",
+    {
+        "DataShareArn": str,
+    },
+)
+
+RedshiftDataShareAssetTypeDef = TypedDict(
+    "RedshiftDataShareAssetTypeDef",
+    {
+        "Arn": str,
+    },
+)
+
 RequestDetailsTypeDef = TypedDict(
     "RequestDetailsTypeDef",
     {
@@ -989,6 +1024,7 @@ RequestDetailsTypeDef = TypedDict(
         "ExportRevisionsToS3": "ExportRevisionsToS3RequestDetailsTypeDef",
         "ImportAssetFromSignedUrl": "ImportAssetFromSignedUrlRequestDetailsTypeDef",
         "ImportAssetsFromS3": "ImportAssetsFromS3RequestDetailsTypeDef",
+        "ImportAssetsFromRedshiftDataShares": "ImportAssetsFromRedshiftDataSharesRequestDetailsTypeDef",
     },
     total=False,
 )
@@ -1001,6 +1037,7 @@ ResponseDetailsTypeDef = TypedDict(
         "ExportRevisionsToS3": "ExportRevisionsToS3ResponseDetailsTypeDef",
         "ImportAssetFromSignedUrl": "ImportAssetFromSignedUrlResponseDetailsTypeDef",
         "ImportAssetsFromS3": "ImportAssetsFromS3ResponseDetailsTypeDef",
+        "ImportAssetsFromRedshiftDataShares": "ImportAssetsFromRedshiftDataSharesResponseDetailsTypeDef",
     },
     total=False,
 )
@@ -1115,7 +1152,7 @@ UpdateAssetResponseTypeDef = TypedDict(
     {
         "Arn": str,
         "AssetDetails": "AssetDetailsTypeDef",
-        "AssetType": Literal["S3_SNAPSHOT"],
+        "AssetType": AssetTypeType,
         "CreatedAt": datetime,
         "DataSetId": str,
         "Id": str,
@@ -1153,7 +1190,7 @@ UpdateDataSetResponseTypeDef = TypedDict(
     "UpdateDataSetResponseTypeDef",
     {
         "Arn": str,
-        "AssetType": Literal["S3_SNAPSHOT"],
+        "AssetType": AssetTypeType,
         "CreatedAt": datetime,
         "Description": str,
         "Id": str,
